# Common description used for all packages
%global maindesc WebAuth is a cookie-based web authentication system built on top of \
Kerberos.  It relies on a central authentication server that handles all \
user authentication for a domain and creates user authentication \
credentials for any web server that needs strong authentication. \
%{nil}

# Enable Perl for Fedora, disable for CentOS/RHEL (for now)
%if 0%{?fedora}
%bcond_without perl
%else
%bcond_with perl
%endif

Name:           webauth
Version:        4.7.0
Release:        2%{?dist}
Summary:        A cookie-based web authentication system built on Kerberos

License:        MIT
URL:            https://webauth.stanford.edu/
Source0:        https://web.stanford.edu/services/%{name}/dist/%{name}-%{version}.tar.xz

# WebAuth Apache httpd module configs
Source1:        00-webauth.conf
Source2:        01-webauthldap.conf
Source3:        02-webkdc.conf

# Fix for OpenSSL 1.1 (from Debian)
Patch0001:      0001-Fix-OpenSSL-library-probe.patch

# Fedora patches
Patch1001:      0001-Use-correct-directory-path-for-apache-httpd-modules.patch

BuildRequires:  httpd-devel
BuildRequires:  pkgconfig(apr-1)
BuildRequires:  pkgconfig(apr-util-1)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libremctl)
BuildRequires:  pkgconfig(libssl)

BuildRequires:  openldap-devel

%if %{with perl}
BuildRequires:  perl(Authen::OATH)
BuildRequires:  perl(CGI::Application)
BuildRequires:  perl(CGI::Application::Plugin::AutoRunmode)
BuildRequires:  perl(CGI::Application::Plugin::Forward)
BuildRequires:  perl(CGI::Application::Plugin::TT)
BuildRequires:  perl(CGI::Application::Plugin::Redirect)
BuildRequires:  perl(CGI::Fast)
BuildRequires:  perl(Crypt::GeneratePassword)
BuildRequires:  perl(FreezeThaw)
BuildRequires:  perl(Getopt::Long::Descriptive)
BuildRequires:  perl(IPC::Run)
BuildRequires:  perl(JSON)
BuildRequires:  perl(MIME::Base32)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Cache::Memcached)
BuildRequires:  perl(Net::Remctl)
BuildRequires:  perl(Template)
BuildRequires:  perl(Test::MinimumVersion)
BuildRequires:  perl(Test::Pod)
BuildRequires:  perl(Test::Strict)
BuildRequires:  perl(Time::Duration)
BuildRequires:  perl(Date::Parse)
BuildRequires:  perl(URI)
BuildRequires:  perl(WWW::Mechanize)
BuildRequires:  perl(LWP)
BuildRequires:  perl(XML::Parser)
BuildRequires:  perl-generators
BuildRequires:  perl-devel
%endif

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool


%description
%{maindesc}

%package -n mod_webauth
Summary:        Apache module for WebAuth authentication
Requires:       libwebauth%{?_isa} = %{version}-%{release}
%if 0%{?fedora} || 0%{?rhel} >= 8
Suggests:       mod_webauthldap
%endif

%description -n mod_webauth
%{maindesc}

This package contains the Apache module to do user authentication for
individual web servers.  This module does not do authorization; for an
approach to LDAP-based authorization that works well with WebAuth, see
mod_webauthldap.


%package -n mod_webauthldap
Summary:        Apache module for WebAuth LDAP lookup and authorization
Requires:       mod_webauth%{?_isa} = %{version}-%{release}
Requires:       cyrus-sasl-gssapi%{?_isa}
Requires:       libwebauth%{?_isa} = %{version}-%{release}

%description -n mod_webauthldap
%{maindesc}

This package contains an Apache module to do LDAP-based authorization
after a WebAuth authentication and retrieve LDAP information about the
authenticated user.  It only supports GSS-API binds and requires WebAuth
be used as the authentication method.

%package -n mod_webkdc
Summary:        Apache modules for a WebAuth authentication KDC
Requires:       libwebauth%{?_isa} = %{version}-%{release}

%description -n mod_webkdc
%{maindesc}

This package contains the Apache module for the central authentication
server for a particular site.  Only one such server is needed; all web
servers that use WebAuth will talk to this server to obtain and verify
authentication credentials.

%if %{with perl}
%package -n perl-WebAuth
Summary:        Perl library for WebAuth authentication
Requires:       libwebauth%{?_isa} = %{version}-%{release}
Requires:       perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description -n perl-WebAuth
%{maindesc}

This package contains the Perl bindings to the WebAuth library, which
does token encoding and decoding and other lower-level parts of the
WebAuth protocol.

%package -n perl-WebKDC
Summary:        Perl libraries for WebAuth central login server
Requires:       perl-WebAuth = %{version}-%{release}
Requires:       perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

BuildArch:      noarch

%description -n perl-WebKDC
%{maindesc}

This package contains the WebKDC Perl modules that support the WebLogin
server, which handles user authentication and the establishment of
initial authentication credentials.

%endif

%package tests
Summary:        Tests for the WebAuth authentication modules
Requires:       mod_webauth = %{version}-%{release}
Requires:       perl-WebAuth = %{version}-%{release}
%if 0%{?fedora} || 0%{?rhel} >= 8
Suggests:       mod_php
%endif
BuildArch:      noarch

%description tests
%{maindesc}

This package contains test HTML files and Apache configuration
fragments to test a new installation of the WebAuth modules.

%package utils
Summary:        Command-line utilities for WebAuth authentication
Requires:       libwebauth%{?_isa} = %{version}-%{release}

%description utils
%{maindesc}

This package contains an additional command-line tool to manipulate
WebAuth keyrings.

%if %{with perl}
%package weblogin
Summary:        Central login server for WebAuth authentication
Requires:       perl-WebKDC = %{version}-%{release}
%if 0%{?fedora} || 0%{?rhel} >= 8
Recommends:     httpd
Suggests:       mod_auth_kerb
%endif
BuildArch:      noarch

%description weblogin
%{maindesc}

This package contains the CGI-based WebLogin server that handles initial
user authentication and building authentication tokens for WebAuth
servers.  Only one WebLogin server is needed to support a site WebAuth
installation.  It is normally run on the same system as the WebKDC.

%endif

%package -n libwebauth
Summary:        Shared libraries for WebAuth authentication

%description -n libwebauth
%{maindesc}

This package contains the shared library used by the WebAuth modules,
Perl bindings, and command-line utilities.  It does token encoding and
decoding and other lower-level parts of the WebAuth protocol.

%package -n libwebauth-static
Summary:        Static library for WebAuth authentication
Requires:       libwebauth-devel%{?_isa} = %{version}-%{release}

%description -n libwebauth-static
%{maindesc}

This package contains the static library needed to compile and
link programs that use libwebauth.

%package -n libwebauth-devel
Summary:        Development files for WebAuth authentication
Requires:       libwebauth%{?_isa} = %{version}-%{release}

%description -n libwebauth-devel
%{maindesc}

This package contains the symlinks and headers needed to
compile and link programs that use libwebauth.


%prep
%autosetup -p1


%build
autoreconf -fiv

%if %{with perl}
# Tell Perl build system to install to the right place
export WEBAUTH_PERL_FLAGS="--installdirs vendor --create_packlist 0"
%endif

%configure --enable-webkdc %{?with_perl:--enable-perl} %{!?with_perl:--disable-perl} --with-apxs=%{_bindir}/apxs --enable-reduced-depends
%make_build


%install
%make_install

mkdir -p %{buildroot}%{_httpd_modconfdir}
install -pm 0644 %{SOURCE1} %{buildroot}%{_httpd_modconfdir}/00-webauth.conf
install -pm 0644 %{SOURCE2} %{buildroot}%{_httpd_modconfdir}/01-webauthldap.conf
install -pm 0644 %{SOURCE3} %{buildroot}%{_httpd_modconfdir}/02-webkdc.conf

%if %{with perl}
mkdir -p %{buildroot}%{perl_vendorlib}
mv %{buildroot}%{perl_vendorarch}/WebKDC* %{buildroot}%{perl_vendorlib}
mv %{buildroot}%{perl_vendorarch}/WebLogin* %{buildroot}%{perl_vendorlib}

mkdir -p %{buildroot}%{_datadir}/webauth/{conf,htdocs}
cp -a tests/mod_webauth/conf/*.conf %{buildroot}%{_datadir}/webauth/conf
cp -a tests/mod_webauth/htdocs/ldaptests %{buildroot}%{_datadir}/webauth/htdocs
cp -a tests/mod_webauth/htdocs/tests %{buildroot}%{_datadir}/webauth/htdocs
%endif

%if ! %{with perl}
# weblogin is useless without perl components
rm -rf %{buildroot}%{_datadir}/weblogin
%endif

find %{buildroot} -name '*.la' -delete

%if %{with perl}
%check
make check
%endif


%post -n libwebauth -p /sbin/ldconfig
%postun -n libwebauth -p /sbin/ldconfig


%files -n libwebauth
%license LICENSE
%{_libdir}/*.so.*

%files -n libwebauth-static
%{_libdir}/*.a

%files -n libwebauth-devel
%{_includedir}/webauth/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%if %{with perl}
%files -n perl-WebAuth
%{perl_vendorarch}/WebAuth/
%{perl_vendorarch}/auto/WebAuth/
%{perl_vendorarch}/WebAuth.*
%{_mandir}/man3/WebAuth*

%files -n perl-WebKDC
%{perl_vendorlib}/WebKDC/
%{perl_vendorlib}/WebKDC.*
%{perl_vendorlib}/WebLogin.*
%{_mandir}/man3/WebKDC*
%{_mandir}/man3/WebLogin*
%endif

%files -n mod_webauth
%{_httpd_moddir}/mod_webauth.so
%{_httpd_modconfdir}/00-webauth.conf

%files -n mod_webauthldap
%{_httpd_moddir}/mod_webauthldap.so
%{_httpd_modconfdir}/01-webauthldap.conf

%files -n mod_webkdc
%{_httpd_moddir}/mod_webkdc.so
%{_httpd_modconfdir}/02-webkdc.conf

%files utils
%{_bindir}/wa_*
%{_mandir}/man1/wa_*

%if %{with perl}
%files tests
%{_datadir}/webauth/

%files weblogin
%{_datadir}/weblogin/
%endif

%changelog
* Mon May 15 2017 Neal Gompa <ngompa@datto.com> - 4.7.0-2
- Make the tests and weblogin subpackages noarch

* Fri May  5 2017 Neal Gompa <ngompa@datto.com> - 4.7.0-1
- Initial packaging
